<?php
/*
 * Plugin Name: Example plugin for SVG Logo and Title Effects for WordPress
 * Description: Example code showing how to create a plugin for SVG Logo and Title Effects. Consult the documentation for more.
 * Version: 1.0.0
 * Author: Dashed Slug <info@dashed-slug.net>
 * Author URI: http://dashed-slug.net
 * License: GPLv2 or later
 */

// don't load directly
defined( 'ABSPATH' ) || die( '-1' );

/**
 * Adds 'Final Frontier Old Style', a free-for-commercial-use font by Allen R. Walden, to the list of available fonts.
 *
 * @param array $fonts This is an array of font definitions. Add your font data to this array.
 */
function slate_example_fonts( $fonts ) {
	$fonts['Final Frontier Old Style'] = array(
		'url' => plugin_dir_url( 'slate-plugin-example/fonts/allen-r-walden_final-frontier-old-style.ttf', __FILE__ ) . 'allen-r-walden_final-frontier-old-style.ttf' );
	return $fonts;
}

add_filter( 'slate_font_files_or_urls', 'slate_example_fonts' );

/**
 * Adds SVG fill patterns to the collection of fill patterns available to SVG Logo and Title Effects. You may specify individual
 * PHP template files, or entire folders/directories. Here we add any PHP templates under the fills directory.
 *
 * @param array $file_names An array of file names and directory names to load. Add to this array.
 */
function slate_example_fills( $file_names ) {
	$file_names[] = realpath( __DIR__ . '/fills/' );
	return $file_names;
}

add_filter( 'slate_fill_files', 'slate_example_fills' );

/**
 * Adds SVG filter templates to the collection of filter templates available to SVG Logo and Title Effects. You may specify individual
 * PHP template files, or entire folders/directories. Here we add any PHP templates under the filters directory.
 *
 * @param array $file_names An array of file names and directory names to load. Add to this array.
 */
function slate_example_filters( $file_names ) {
	$file_names[] = realpath( __DIR__ . '/filters/' );
	return $file_names;
}

add_filter( 'slate_filter_files', 'slate_example_filters' );

/**
 * Adds a preset showcasing the resources we just added. A preset is a full shortcode with sensible values that the
 * end user may start from before they modify to suit their needs. If Visual Composer is available, these will
 * be available as VC templates.
 *
 * @param array $presets This is an array of preset definitions. Add your preset to this array.
 */
function slate_example_presets( $presets ) {
	$presets['Space Path'] = '[slate_plain _font_family="Final Frontier Old Style" _font_size="36pt" _stroke="#000000" _stroke_width="0px" fill="color" fill_color_color="#226fc1"]<i>SPACE PATH</i>[/slate_plain]';

	return $presets;
}

add_filter( 'slate_presets', 'slate_example_presets' );
